%% -------------------------Constants--------------------------------------
% -------------------------------------------------------------------------

%-------------------global room values-------------------------------------
room_height = 3;
depth_external_wall = 0.15;
depth_internal_wall = 0.10;
depth_floor = 0.25;
depth_external_ceiling = depth_floor;
depth_wall_sheathing = 0.002; %thickness of the wallpaper
depth_floor_sheathing = 0.003; %thickness of the floor covering (gulvbelegg)
depth_ceiling_sheathing = 0.01; %thickness of the ceiling covering (trekledning)
ACH_infiltration = 0.2; %air changes per hour (ACHs). According to Novakovic typical value is 0.1-0.3.
ACH_ventilation = 1; %air changes per hour (ACHs)
%Radiatiors
Radiator_heat_effect = 1000; %W
htc_rad = 7; %normally between 6-8 W/(m^2*K) according to Novakovic
A_rad = 1; %the radiators radiation area

%-------------------global U-factors and heat transfer coefficients--------
%Wall
U_external_wall = 0.31; %found in table 211 in u_value_wall.pdf from sintef byggforsk
U_internal_wall = 0.41; %found in table 214 in u_value_wall.pdf from sintef byggforsk
htc_wallair = 3; %typical values found in novakovic
lambda_external_wall = U_external_wall*depth_external_wall; %equation from sintef byggforsk
lambda_wall_sheathing = 0.03; % lambda value for 6mm gypsum board (gipsplate) found in varmekonduktivitet_varmemotstand_bygningsmaterialer.pdf from sintef byggforsk
%Window
U_window = 2.8; % Isolerglass 2-lags glass. Found in u_value_window.pdf from nor-dan
htc_windowwall = 5; %typical values found in novakovic
htc_windowair = 3; %typical values found in novakovic
%Ceiling
U_external_ceiling = 0.22; %found in table 22 in u_value_ceiling.pdf from sintef byggforsk
htc_ceilingair = 3; %typical values found in novakovic
lambda_external_ceiling = U_external_wall*depth_external_ceiling; %equation from sintef byggforsk
lambda_ceiling_sheathing = U_external_ceiling*depth_ceiling_sheathing;
%Floor
U_floor = 0.15; % found in table 23 in u_value_floor.pdf from sintef byggforsk (this value depends on the area of the floor, but does not vary much. Therefor a fixed u-value is used in every room although the areas are varying)

%-------------------physical values - external walls-----------------------
%specific heat capacity - J/(kg*K)
cp_external_wall = 2700*0.1+1030*0.9; %assuming the wall consists of 10% wood with specific heat capacity 2700J/(kg*K) and 90% insulation with specific heat capacity 1030J/(kg*K)
%density - kg/m^3
rho_external_wall = 500*0.1+31*0.9; %assuming the wall consists of 10% wood with density 500kg/m^3 and 90% insulation with specific heat capacity 31kg/m^3

%-------------------physical values - internal walls--------------------------
%specific heat capacity - J/(kg*K)
cp_internal_wall = 2700*0.1+1030*0.9; %assuming the wall consists of 10% wood with specific heat capacity 2700J/(kg*K) and 90% insulation with specific heat capacity 1030J/(kg*K)
%density - kg/m^3
rho_internal_wall = 500*0.1+31*0.9; %assuming the wall consists of 10% wood with density 500kg/m^3 and 90% insulation with specific heat capacity 31kg/m^3

%-------------------physical values - ceiling------------------------------
%specific heat capacity - J/(kg*K)
cp_ceiling = 2700*0.1+1030*0.9; %assuming the wall consists of 10% wood with specific heat capacity 2700J/(kg*K) and 90% insulation with specific heat capacity 1030J/(kg*K)
%density - kg/m^3
rho_ceiling = 500*0.1+31*0.9; %assuming the ceiling consists of 10% wood with density 500kg/m^3 and 90% insulation with specific heat capacity 31kg/m^3

%-------------------physical values - floor--------------------------------
%specific heat capacity - J/(kg*K)
cp_floor = 2700*0.1+1030*0.9; %assuming the floor consists of 10% wood with specific heat capacity 2700J/(kg*K) and 90% insulation with specific heat capacity 1030J/(kg*K)
%density - kg/m^3
rho_floor = 500*0.1+31*0.9; %assuming the floor consists of 10% wood with density 500kg/m^3 and 90% insulation with specific heat capacity 31kg/m^3

%-------------------physical values - air----------------------------------
%conductivity - W/(m*K)
lambda_air = 0.025;
%density - kg/m^3
rho_air = 1.2;
%specific heat capacity - J/(kg*K)
cp_air = 1012;
%kinematic viscosity - m^2/s
v_air = 15*10^(-6);
%Prandtl's number - dimensionless
Pr_air = 0.72;

%-------------------physical values - water------------------------------
%diffusivity = (thermal conductivity)/(volumetric heat capacity) - m^2/s
alpha_water = 0.00000016;
%conductivity - W/(m*K)
lambda_water = 0.66;
%density - kg/m^3
rho_water = 980;
%specific heat capacity - J/(kg*K)
cp_water = 4180;
%kinematic viscosity - m^2/s
v_water = 0.5*10^(-6);
%Prandtl's number - dimensionless
Pr_water = 3.6;

%-------------------other physical values----------------------------------
%conductivity steel - W/(m*K)
lambda_steel = 40;
%conductivity insulation - W/(m*K)
lambda_insulation = 0.05;
%emissivity for tube surface
epsilon_pipe = 0.5;
%emissivity for insulation surface
epsilon_insulation = 0.8;
%specific heat capacity steel - J/(kg*K)
cp_steel = 460;
%specific heat capacity copper - J/(kg*K)
cp_copper = 390;
%specific heat capacity aluminum - J/(kg*K)
cp_aluminum = 900;
%density steel - kg/m^3
rho_steel = 7800;
%coefficient of surface conductance by radiation 
hrad = 4;
%coefficient of surface conductance by convection 
hconv = 3.7;

%--------------------------------------------------------------------------

