clear all
close all
clc %clears the command window

%% -----------------------initial values-----------------------------------
average_ext_temp = 5;
indoor_temp_adj_rooms = 18;
return_air_temp = 18;
internal_temp_room_init = 20;
internal_temp_wall_init = 20;
internal_temp_floor_init = 20;
internal_temp_ceiling_init = 20;
water_temp_from_supply = 110;
room_set_temp=18;
ventilation_temp_set = 18;

%PID values
Kp_room = 50;
Ki_room = 0.05;
Kd_room = 0;
Kp_hc = 0.2;
Ki_hc = 0.002;
Kd_hc = 0;

%definition of time
second = 1;
minute = 60*second;
hour = 60*minute;
day = 24*hour;

%% -----------------------load parameters----------------------------------
%loads all parameters used in the model
run constants;
run room_values;
run input_parameters;
run preprocessing;
run mpc_preparations;
run mpc;

%% ---------------------- simulation --------------------------------------
numdays = 1;    %number of days to simulate
tstart = 0;      %Sim start time
tstop = numdays*day;    % Sim stop time, day is equal to twenty-four hours (60seconds*60minutes*24hours)
tstep = 2*minute-10;    % Sim step time
t=tstart:tstep:tstop;   %time array

%start simulation
sim active_building_new_model_mpc_one_room

%% --------------------- calculation of energy consumption ----------------

% %energy consumption - ventilation
% run energy_consumption_ventilation;

%energy consumption - radiators
run energy_consumption_radiators;

sim active_building_new_model_pid

run energy_consumption_radiators2;
% room_set_temp=18;
% %start simulation
% sim active_half_building_model
% 
% %% ---------------------------calculation of energy consumption------------
% 
% %energy consumption - ventilation
% run energy_consumption_ventilation;
% 
% %energy consumption - radiators
% run energy_consumption_radiators2;


%% ----------------------------plot results--------------------------------

%difference between y and y_hat
figure('Name','Estimated output vs real output','NumberTitle','off')
plot(t, y_hat_k133, t, y_k133)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('y_{est}','y')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('difference between y_k133 and y_hat_k133')

%y
figure('Name','Room temperature controlled by MPC','NumberTitle','off')
plot(t, y_k133)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('room temperature')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('temperature room k133 - MPC controller')

%difference between y and y_hat
figure('Name','Estimated output vs real output','NumberTitle','off')
plot(t, y_hat_k134, t, y_k134)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('y_{est}','y')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('difference between y_k134 and y_hat_k134')

%difference between y and y_hat
figure('Name','Estimated output vs real output','NumberTitle','off')
plot(t, y_hat_k135, t, y_k135)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('y_{est}','y')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('difference between y_k135 and y_hat_k135')

%difference between y and y_hat
figure('Name','Estimated output vs real output','NumberTitle','off')
plot(t, y_hat_k136, t, y_k136)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('y_{est}','y')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('difference between y_k136 and y_hat_k136')

%difference between y and y_hat
figure('Name','Estimated output vs real output','NumberTitle','off')
plot(t, y_hat_k143, t, y_k143)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('y_{est}','y')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('difference between y_k143 and y_hat_k143')

%difference between y and y_hat
figure('Name','Estimated output vs real output','NumberTitle','off')
plot(t, y_hat_k164, t, y_k164)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('y_{est}','y')
xlabel('Time [h]')
ylabel('temperature [celsius]')
title('difference between y_k164 and y_hat_k164')

%difference between x and x_hat
figure('Name','Estimated states','NumberTitle','off')
subplot(4,2,1);
plot(t, x_hat_k133(:,1))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x1_{est}')
xlabel('Time [h]')
ylabel('state [x1]')
title('x1_hat_k133')
subplot(4,2,2);
plot(t, x_hat_k133(:,2))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x2_{est}')
xlabel('Time [h]')
ylabel('state [x2]')
title('x2_hat_k133')
subplot(4,2,3);
plot(t, x_hat_k133(:,3))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x3_{est}')
xlabel('Time [h]')
ylabel('state [x3]')
title('x3_hat_k133')
subplot(4,2,4);
plot(t, x_hat_k133(:,4))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x4_{est}')
xlabel('Time [h]')
ylabel('state [x4]')
title('x4_hat_k133')
subplot(4,2,5);
plot(t, x_hat_k133(:,5))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x5_{est}')
xlabel('Time [h]')
ylabel('state [x5]')
title('x5_hat_k133')
subplot(4,2,6);
plot(t, x_hat_k133(:,6))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x6_{est}')
xlabel('Time [h]')
ylabel('state [x6]')
title('x6_hat_k133')
subplot(4,2,7);
plot(t, x_hat_k133(:,7))
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('x7_{est}')
xlabel('Time [h]')
ylabel('state [x7]')
title('x7_hat_k133')

%energy consumption
figure('Name','Energy consumption','NumberTitle','off')
semilogy(t, energy_comsumption_radiator_k133, t, energy_comsumption_radiator_k133_2)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('energy usage MPC - room temperature varying','energy usage PID - room temperature varying')
xlabel('Time [h]')
ylabel('Energy [W]')
title('Energy consumption development')

% %ventilation temperature
% figure('Name','Ventilation temperature development','NumberTitle','off')
% plot(t, ventilation_temperature, t, ventilation_temperature2)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('ventilation temp','ventilation temp 2')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Ventilation temperature')

% %ventilation temperature after fan
% figure('Name','Ventilation temperature development after fan','NumberTitle','off')
% plot(t, ventilation_temperature_after_fan)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('ventilation temp after fan')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Ventilation temperature after fan')

% %ventilation temperature after hru
% figure('Name','Ventilation temperature development after hru','NumberTitle','off')
% plot(t, ventilation_temperature_after_hru)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('ventilation temp after hru')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Ventilation temperature after hru')

% %water temperature from Shunt valve
% figure('Name','Water temperature from Shunt valve','NumberTitle','off')
% plot(t, water_to_HC)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('Water temperature from Shunt valve')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Water temperature from Shunt valve')

% %water temperature from heating coil
% figure('Name','Water temperature from heating coil','NumberTitle','off')
% plot(t, water_temp_out)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('Water temperature from heating coil')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Water temperature from heating coil')

% %control signal water and relative water response
% figure('Name','Control signal and responce','NumberTitle','off')
% plot(t, q_rel_water, t, control_signal)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('q rel water','control')
% xlabel('Time [h]')
% ylabel('Control signal and responce [percent]')
% title('Control signal and response')

% %temperature development every 24-hour
% figure('Name','Temperature development','NumberTitle','off')
% subplot(2,1,1);
% plot(t, outdoor_temp)
% title('Outdoor temperature development')
% set(gca,'XTick',0:(hour*24):tstop)
% set(gca,'XTickLabel',{'0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20'})
% xlabel('Time [days]')
% ylabel('Temperature [celsius]')
% subplot(2,1,2);
% plot(t, k133_indoor_air_temperature)
% title('Indoor temperature development')
% set(gca,'XTick',0:(hour*24):tstop)
% set(gca,'XTickLabel',{'0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20'})
% legend('k133')
% xlabel('Time [days]')
% ylabel('Temperature [celsius]')

%--------------------------------------------------------------------------