clear all
close all
clc %clears the command window

%% -----------------------initial values-----------------------------------
average_ext_temp = 5;
indoor_temp_adj_rooms = 18;
return_air_temp = 18;
internal_temp_room_init = 20;
internal_temp_wall_init = 20;
internal_temp_floor_init = 20;
internal_temp_ceiling_init = 20;
water_temp_from_supply = 110;
room_set_temp=21;
ventilation_temp_set = 18;

%PID values
Kp_room = 50;
Ki_room = 0.05;
Kd_room = 0;
Kp_hc = 0.2;
Ki_hc = 0.002;
Kd_hc = 0;

%definition of time
second = 1;
minute = 60*second;
hour = 60*minute;
day = 24*hour;

%% -----------------------load parameters----------------------------------
%loads all parameters used in the model
run constants;
run room_values;
run input_parameters;
run preprocessing;

%% ---------------------- system identification ---------------------------
numdays = 1;    %number of days to simulate
tstart = 0;      %Sim start time
tstop = numdays*day;    % Sim stop time, day is equal to twenty-four hours (60seconds*60minutes*24hours)
tstep = minute/3;    % Sim step time
t=tstart:tstep:tstop;   %time array

%start simulation
sim active_building_new_model_pid

%% --------------------- calculation of energy consumption ----------------

% %energy consumption - ventilation
% run energy_consumption_ventilation;

%energy consumption - radiators
run energy_consumption_radiators;

% room_set_temp=21;
% %start simulation
% sim active_building_new_model_pid

%% ---------------------------calculation of energy consumption------------

% %energy consumption - ventilation
% run energy_consumption_ventilation;
 
% %energy consumption - radiators
% run energy_consumption_radiators2;

%% ----------------------------plot results--------------------------------

% %energy consumption ventilation
% figure('Name','Energy consumption - ventilation','NumberTitle','off')
% plot(t, energy_comsumption_ventilation)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('energy consumption, varying set temperature')
% xlabel('Time [h]')
% ylabel('Energy [W]')
% title('Energy consumption development')

%energy consumption radiators
figure('Name','Energy consumption - radiators','NumberTitle','off')
semilogy(t, sum_energy_comsumption_radiator)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('energy consumption, varying set temperature')
xlabel('Time [h]')
ylabel('Energy [W]')
title('Energy consumption development')

%outdoor temperature development
figure('Name','Outdoor temperature development','NumberTitle','off')
plot(t, outdoor_temp)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('Outdoor temp')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Outdoor temperature development')

%indoor temperature development
figure('Name','Indoor temperature development','NumberTitle','off')
plot(t, k133_indoor_air_temperature)
title('Indoor temperature development')
set(gca,'XTick',0:(hour*24):tstop)
set(gca,'XTickLabel',{'0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20'})
legend('k133')
xlabel('Time [days]')
ylabel('Temperature [celsius]')

%radiator temperature development in the rooms 
figure('Name','Radiator temperature development','NumberTitle','off')
plot(t, k133_radiator_temp, t, k133_radiator_gain_signal)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('radiator temp k133','radiator gain k133')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Radiator temperature development')

%ventilation temperature
figure('Name','Ventilation temperature development','NumberTitle','off')
plot(t, ventilation_temperature)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('ventilation temp')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Ventilation temperature')

% %ventilation temperature after fan
% figure('Name','Ventilation temperature development after fan','NumberTitle','off')
% plot(t, ventilation_temperature_after_fan)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('ventilation temp after fan')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Ventilation temperature after fan')

% %ventilation temperature after hru
% figure('Name','Ventilation temperature development after hru','NumberTitle','off')
% plot(t, ventilation_temperature_after_hru)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('ventilation temp after hru')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Ventilation temperature after hru')

% %water temperature from Shunt valve
% figure('Name','Water temperature from Shunt valve','NumberTitle','off')
% plot(t, water_to_HC)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('Water temperature from Shunt valve')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Water temperature from Shunt valve')

% %water temperature from heating coil
% figure('Name','Water temperature from heating coil','NumberTitle','off')
% plot(t, water_temp_out)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('Water temperature from heating coil')
% xlabel('Time [h]')
% ylabel('Temperature [celsius]')
% title('Water temperature from heating coil')

% %control signal water and relative water response
% figure('Name','Control signal and responce','NumberTitle','off')
% plot(t, q_rel_water, t, control_signal)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('q rel water','control')
% xlabel('Time [h]')
% ylabel('Control signal and responce [percent]')
% title('Control signal and response')

% %temperature development every 24-hour
% figure('Name','Temperature development','NumberTitle','off')
% subplot(2,1,1);
% plot(t, outdoor_temp)
% title('Outdoor temperature development')
% set(gca,'XTick',0:(hour*24):tstop)
% set(gca,'XTickLabel',{'0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20'})
% xlabel('Time [days]')
% ylabel('Temperature [celsius]')
% subplot(2,1,2);
% plot(t, k133_indoor_air_temperature)
% title('Indoor temperature development')
% set(gca,'XTick',0:(hour*24):tstop)
% set(gca,'XTickLabel',{'0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20'})
% legend('k133')
% xlabel('Time [days]')
% ylabel('Temperature [celsius]')

%--------------------------------------------------------------------------