clear all
close all
clc %clears the command window

%% -----------------------initial values-----------------------------------
ventilation_temp_set = 18;
return_air_temp = 18;
average_ext_temp = 5;
internal_temp_room_init = 20;
internal_temp_wall_init = 20;
internal_temp_floor_init = 20;
internal_temp_ceiling_init = 20;
water_temp_from_supply = 110;

%PID values
Kp_hc = 0.8;
Ki_hc = 0.00;
Kd_hc = 0;

%definition of time
second = 1;
minute = 60*second;
hour = 60*minute;
day = 24*hour;

%% -----------------------load parameters----------------------------------
%loads all parameters used in the model
run constants;
run input_parameters;
run preprocessing;

%% -----------------------------simulation---------------------------------
numdays = 1;    %number of days to simulate
tstart = 0;      %Sim start time
tstop = numdays*day;    % Sim stop time, day is equal to twenty-four hours (60seconds*60minutes*24hours)
tstep = minute/3;    % Sim step time
t=tstart:tstep:tstop;   %time array

% %start simulation
% sim ventilation
% 
% % ---------------------------calculation of energy consumption------------
% 
% %energy consumption - ventilation
% temp_diff = water_to_HC-water_from_HC;
% [energy_ventilation_1] = qw_hc*cp_water*rho_water*temp_diff;
% 
% energy_ventilation_sum_1 = 0;
% for i=1:length(t)
%     energy_ventilation_sum_1=energy_ventilation_sum_1+(energy_ventilation_1(i));
% end
% 
% average_energy_ventilation_1 = energy_ventilation_sum_1/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.
% 
% kilowatt_hours_used_1 = average_energy_ventilation_1*numdays*24


% ventilation_temp_set = 16;
% %start simulation
sim ventilation_hru

% ---------------------------calculation of energy consumption------------

%energy consumption - ventilation
temp_diff = water_to_HC-water_from_HC;
[energy_ventilation_2] = qw_hc*cp_water*rho_water*temp_diff;

energy_ventilation_sum_2 = 0;
for i=1:length(t)
    energy_ventilation_sum_2=energy_ventilation_sum_2+(energy_ventilation_2(i));
end

average_energy_ventilation_2 = energy_ventilation_sum_2/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.

kilowatt_hours_used_2 = average_energy_ventilation_2*numdays*24


% ---------------calculation of energy consumption using air temp----------

% %start simulation
% sim ventilation
% 
% %energy consumption - ventilation
% temp_diff = ventilation_temperature-ventilation_temperature_after_fan;
% [energy_ventilation_2] = qa_hc*cp_air*rho_air*temp_diff;
% 
% energy_ventilation_sum_2 = 0;
% for i=1:length(t)
%     energy_ventilation_sum_2=energy_ventilation_sum_2+(energy_ventilation_2(i));
% end
% 
% average_energy_ventilation_2 = energy_ventilation_sum_2/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.
% 
% kilowatt_hours_used_2 = average_energy_ventilation_2*numdays*24


% --------------calculation of energy consumption using air temp----------

% qa_hc = 0.7713; %90% of normal
% 
% %start simulation
% sim ventilation
% 
% %energy consumption - ventilation
% temp_diff = ventilation_temperature-ventilation_temperature_after_fan;
% [energy_ventilation_3] = qa_hc*cp_air*rho_air*temp_diff;
% 
% energy_ventilation_sum_3 = 0;
% for i=1:length(t)
%     energy_ventilation_sum_3=energy_ventilation_sum_3+(energy_ventilation_3(i));
% end
% 
% average_energy_ventilation_3 = energy_ventilation_sum_3/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.
% 
% kilowatt_hours_used_3 = average_energy_ventilation_3*numdays*24



%% ----------------------------plot results--------------------------------

% %energy consumption 
% figure('Name','Energy consumption','NumberTitle','off')
% semilogy(t, energy_ventilation_1, t, energy_ventilation_2)
% set(gca,'XTick',0:(hour*3):tstop)
% set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
% legend('energy - ventilation without HRU', 'energy - ventilation with HRU')
% xlabel('Time [h]')
% ylabel('Energy [W]')
% title('Energy consumption development')

%energy consumption
figure('Name','Energy consumption','NumberTitle','off')
semilogy(t, energy_ventilation_2)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('energy - ventilation temperature varying')
xlabel('Time [h]')
ylabel('Energy [W]')
title('Energy consumption development')

%ventilation temperature development after heat recovery unit 
figure('Name','Air temperature development','NumberTitle','off')
plot(t, ventilation_temperature_after_hru, t, outdoor_temp)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('Air temperature after HRU','Outdoor air temperature')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Air temperature development')

%ventilaton temperature development
figure('Name','ventilation temperature','NumberTitle','off')
plot(t, ventilation_temperature)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Ventilation temperature development')

%water temperature development
figure('Name','water to heating coil','NumberTitle','off')
plot(t, water_to_HC, t, water_from_supply, t, water_from_HC, t, q_rel_water, t, control_signal)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('water to HC','water from supply','water from HC','q rel water','control')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Water to heating coil')

%control signal water and relative water response
figure('Name','Control signal and responce','NumberTitle','off')
plot(t, q_rel_water, t, control_signal)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('q rel water','control')
xlabel('Time [h]')
ylabel('Control signal and responce [percent]')
title('Control signal and response')

%outdoor temperature development
figure('Name','outdoor temperature','NumberTitle','off')
plot(t, outdoor_temp)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Outdoor temperature development')
%--------------------------------------------------------------------------