clear all
close all
clc %clears the command window

%% -----------------------initial values-----------------------------------
ventilation_temp_set = 18;
return_air_temp = 18;
average_ext_temp = 5;
internal_temp_room_init = 20;
internal_temp_wall_init = 20;
internal_temp_floor_init = 20;
internal_temp_ceiling_init = 20;
water_temp_from_supply = 110;

%PID values
Kp_hc = 5;
Ki_hc = 0.01;
Kd_hc = 0;

%definition of time
second = 1;
minute = 60*second;
hour = 60*minute;
day = 24*hour;

%% -----------------------load parameters----------------------------------
%loads all parameters used in the model
run constants;
run input_parameters;
run preprocessing;

%% -----------------------------simulation---------------------------------
numdays = 1;    %number of days to simulate
tstart = 0;      %Sim start time
tstop = numdays*day;    % Sim stop time, day is equal to twenty-four hours (60seconds*60minutes*24hours)
tstep = minute/6;    % Sim step time
t=tstart:tstep:tstop;   %time array

% %start simulation
% sim ventilation2
% 
% % ---------------------------calculation of energy consumption------------
% 
% %energy consumption - ventilation
% temp_diff = water_to_HC-water_from_HC;
% [energy_ventilation_1] = qw_hc*cp_water*rho_water*temp_diff;
% 
% energy_ventilation_sum_1 = 0;
% for i=1:length(t)
%     energy_ventilation_sum_1=energy_ventilation_sum_1+(energy_ventilation_1(i));
% end
% 
% average_energy_ventilation_1 = energy_ventilation_sum_1/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.
% 
% kilowatt_hours_used_1 = average_energy_ventilation_1*numdays*24
% 

% ---------------calculation of energy consumption using air temp----------

%start simulation
sim ventilation2

%energy consumption - ventilation
temp_diff = ventilation_temperature-ventilation_temperature_after_fan;
[energy_ventilation_2] = qa_hc*cp_air*rho_air*temp_diff;

energy_ventilation_sum_2 = 0;
for i=1:length(t)
    energy_ventilation_sum_2=energy_ventilation_sum_2+(energy_ventilation_2(i));
end

average_energy_ventilation_2 = energy_ventilation_sum_2/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.

kilowatt_hours_used_2 = average_energy_ventilation_2*numdays*24


% % --------------calculation of energy consumption using air temp----------
% 
% %start simulation
% sim ventilation
% 
% %energy consumption - ventilation
% temp_diff = ventilation_temperature-ventilation_temperature_after_fan;
% [energy_ventilation_3] = qa_hc*cp_air*rho_air*temp_diff;
% 
% energy_ventilation_sum_3 = 0;
% for i=1:length(t)
%     energy_ventilation_sum_3=energy_ventilation_sum_3+(energy_ventilation_3(i));
% end
% 
% average_energy_ventilation_3 = energy_ventilation_sum_3/(length(t-1)*1000);  % divided by 1000 to get average energy in kilowatt.
% 
% kilowatt_hours_used_3 = average_energy_ventilation_3*numdays*24
% 


%% ----------------------------plot results--------------------------------

%energy consumption 
figure('Name','Energy consumption','NumberTitle','off')
plot(t, energy_ventilation_2)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('energy - ventilation with HRU')
xlabel('Time [h]')
ylabel('Energy [W]')
title('Energy consumption development')

%ventilation temperature development after heat recovery unit 
figure('Name','Air temperature development','NumberTitle','off')
plot(t, outdoor_temp, t, ventilation_temperature_after_hru)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('Outdoor air temp','Air temp after HRU')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Air temperature development')

%ventilaton temperature development
figure('Name','ventilation temperature','NumberTitle','off')
plot(t, ventilation_temperature)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Ventilation temperature development')

%temperature development every 3rd hour
figure('Name','ventilation temperature','NumberTitle','off')
subplot(2,1,1);
plot(t, ventilation_temperature_after_hru)
title('Temperature development after HRU')
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96','99','102','105','108','111','114','117','120','123','126','129','132','135','138','141','144','147','150','153','156','159','162','165','168','171','174','177','180'})
xlabel('Time [h]')
ylabel('Temperature [celsius]')
subplot(2,1,2);
plot(t, ventilation_temperature)
title('Ventilation temperature development')
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96','99','102','105','108','111','114','117','120','123','126','129','132','135','138','141','144','147','150','153','156','159','162','165','168','171','174','177','180'})
xlabel('Time [h]')
ylabel('Temperature [celsius]')

%water temperature development
figure('Name','water to heating coil','NumberTitle','off')
plot(t, water_to_HC, t, water_from_supply, t, water_from_HC, t, q_rel_water, t, control_signal)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('water to HC','water from supply','water from HC','q rel water','control')
xlabel('Time [h]')
ylabel('Temperature [celsius]')
title('Water to heating coil')

%control signal water and relative water response
figure('Name','Control signal and responce','NumberTitle','off')
plot(t, q_rel_water, t, control_signal)
set(gca,'XTick',0:(hour*3):tstop)
set(gca,'XTickLabel',{'0','3','6','9','12','15','18','21','24','27','30','33','36','39','42','45','48','51','54','57','60','63','66','69','72','75','78','81','84','87','90','93','96'})
legend('q rel water','control')
xlabel('Time [h]')
ylabel('Control signal and responce [percent]')
title('Control signal and response')


%--------------------------------------------------------------------------