function [yhatOut, xhatOut] = kalman(meas, u, meas_dist)
% This Embedded MATLAB Function implements a simple Kalman filter 
% for estimating both the state and output of a linear, discrete-time,
% time-invariant, system given by the following state-space equations:
%
% x(k) = A x(k-1) + B1 u_1(k) + B2 d(k) + w(k)
% y(k) = C x(k-1) + v(k)

% Define storage for the variables that need to persist
% between time periods.
persistent xhat P Q_kalman R_kalman A B1 B2 C
if isempty(P) | isempty(A) | isempty(B1) | isempty(B2) | isempty(C)
% First time through the code so do some initialization
   xhat = [0 0 0 0 0 0 0]';
   P = zeros(7);
   Q_kalman = 0.01*eye(7);
   R_kalman = 0.1*eye(1);
   A = discrete_ss_k133b.a;
   B1 = discrete_ss_k133b.b(:,2);
   B2 = discrete_ss_k133b.b(:,[1 3]);
   C = discrete_ss_k133b.c;
end
% Propagate the state estimate and covariance matrix:
xhat = A*xhat + B1*u + B2*meas_dist;
P = A*P*A' + Q_kalman;
% Calculate the Kalman gain
K = P*C'/(C*P*C' + R_kalman);
% Calculate the measurement residual
resid = meas - C*xhat;
% Update the state and error covariance estimate
xhat = xhat + K*resid;
P = (eye(size(K,1))-K*C)*P*(eye(size(K,1))-K*C)'+K*R_kalman*K';

% Post the results
xhatOut = xhat;
yhatOut = C*xhatOut;