%% ------------------------------- MPC ------------------------------------

%% prediction horizon and intitial values
H_p = 35; %remember to also change H_p in feedforward.m and K_MPC (embedded matlab function)
H_u = H_p; %remember to also change H_u in K_MPC (embedded matlab function)
H_w = 1;

%% system
n = 7; %number of states
l = 1; %number of inputs
m = 1; %number of controlled (measured) outputs.  If this parameter changes remember to also change it in K_MPC (embedded matlab function)
d = 2; %number of measured disturbance inputs

% Epsilon(k) = T(k) - Psi*x(k) - Upsilon*u(k-1) - Xi*Dm(k) (see simulink block labeled mpc)
T1 = ones(m*(H_p-H_w+1), 1)*21; %reference value
T2 = ones(m*(H_p-H_w+1), 1)*18; %reference value


%% ------------------------------room:k133---------------------------------
A_k133 = discrete_ss_k133.a; %dimension n*n
B1_k133 = discrete_ss_k133.b(:,1); %dimension n*l
B2_k133 = discrete_ss_k133.b(:,[2 3]); %dimension n*d
C_k133 = discrete_ss_k133.c; %dimension m*n
C_blockdiag_k133 = blkdiag2(C_k133,H_p); %see equation 2.70 in Maciejowski

%% Define matrices required for the prediction vector equation
% Z(k) = Psi*x(k) + Upsilon*u(k-1) + Theta*DeltaU(k) + Xi*Dm(k) 
Psi_k133 = zeros(m*(H_p-H_w+1), n);
Upsilon_k133 = zeros(m*(H_p-H_w+1), l);
Theta_k133 = zeros(m*(H_p-H_w+1), l*H_u);
Xi_k133 = zeros(m*(H_p-H_w+1), m*(H_p-H_w+1));

%% Creation of Psi, Upsilon, Theta and Xi matrices for z(k+1),z(k+2),...,z(k+Hp):
%Psi
for q = 1:m*(H_p-H_w+1)
   i = q*n-(n-1);
   Psi_k133 = Psi_k133 + C_blockdiag_k133(:, i:i+n-1)*A_k133^q; %tested OK          
end

%Upsilon
Upsilon_temp_k133 = zeros(H_p*n,m);
for p = 0:m*(H_p-H_w+1)-1
    i=p*n+1;
    if p==0
        Upsilon_temp_k133(i:i+n-1,:) = (A_k133^p)*B1_k133;
    else
        Upsilon_temp_k133(i:i+n-1,:) = Upsilon_temp_k133(i-n:i-1)+(A_k133^p)*B1_k133;
    end
end
Upsilon_k133 = C_blockdiag_k133*Upsilon_temp_k133;

%Theta
Theta_k133(:,(1:l)) = Upsilon_k133;
for r = 1:H_u-1
    Theta_k133(:,(l*r+1:l*r+l)) = shiftd(Upsilon_k133,0,r); %tested OK
end

%Xi
Xi1_k133 = zeros(m*(H_p-H_w+1), d);
for s = 0:m*(H_p-H_w+1)-1
    if s==0
        i = 1;
        Xi1_k133 = C_blockdiag_k133(:, i:i+n-1)*B2_k133;
    else
        i = s*n+1;
        Xi1_k133 = Xi1_k133 + C_blockdiag_k133(:, i:i+n-1)*(A_k133^s)*B2_k133;
    end
end

Xi_k133(:,(1:d)) = Xi1_k133;
for t = 1:H_p-1
    Xi_k133(:,(d*t+1:d*t+d)) = shiftd(Xi1_k133,0,t); %tested OK
end



