%% -------------------------Preprocessing----------------------------------
% -------------------------------------------------------------------------

%---------------------------Heating coil-----------------------------------
% water temperature out from the heating coil (celcius)
two_hc = twi_hc-((rho_air*cp_air*qa_hc)/(rho_water*cp_water*qw_hc))*(tao_hc-tai_hc);
%relative cooling of water
epsilon_water = (twi_hc-two_hc)/(twi_hc-tai_hc);
%relative heating of air
epsilon_air = (tao_hc-tai_hc)/(twi_hc-tai_hc);
%specific heat capacity heating coil
if(material_hc==1)
    cp_hc = 0.67*cp_aluminum+0.33*cp_copper;
elseif(material_hc==2)
    cp_hc = cp_copper;
end
%time constant in heating coil (s)
T_hc = (m_hc*cp_hc+rho_water*cp_water*v_water)/(rho_water*cp_water*qw_hc)*(1-epsilon_water);
%gain water to water
K_ww = 1-epsilon_water;
%gain water to air
K_wa = epsilon_air;
%gain air to water
K_aw = epsilon_water;
%gain air to air
K_aa = 1-epsilon_air;
%time constant in heating coil air side
T_aa = (1-epsilon_air-epsilon_water)/(1-epsilon_water)*T_hc;

%---------------------------Heat recovery unit-----------------------------
%time constant in heat recovery unit (s)
Thru = (m_hru*cp_hru)/(2*va_hru*cp_air);
%gain fresh air to heated fresh air
K_12 = 1-eta;
%gain used air to heated fresh air
K_32 = eta;

%--------------------------Pipe 1------------------------------------------
%U-value
Re_p1 = 4*qw_hc/(pi*di_p1*v_water);
Nu_p1 = 0.023*Re_p1^(0.8)*Pr_water^(0.4);
hi_p1 = lambda_water*Nu_p1/di_p1;
R_p1 = do_p1/(2*lambda_steel)*log(do_p1/di_p1)+do_p1/(2*lambda_insulation)*log((do_p1+2*insulation_p1)/do_p1)+do_p1/(do_p1+2*insulation_p1)*1/(hrad+hconv);
U_p1 = 1/R_p1;
tau_p1 = l_p1*pi*di_p1^2/(4*qw_hc);
k1_p1 = hi_p1*di_p1/(hi_p1*di_p1+U_p1*do_p1);
k2_p1 = U_p1*do_p1/(hi_p1*di_p1+U_p1*do_p1);
T1_p1 = di_p1*rho_water*cp_water/(4*hi_p1);
T2_p1 = (do_p1^2-di_p1^2)*rho_steel*cp_steel/(4*(hi_p1*di_p1+U_p1*do_p1));
nD_p1 = tau_p1*k2_p1/T1_p1;
mD_p1 = tau_p1*k1_p1/T1_p1;
KD_p1 = exp(-nD_p1);
TD1_p1 = exp(-mD_p1/2)*T2_p1;
TD2_p1 = exp(mD_p1/2)*T2_p1;

%--------------------------Duct 1------------------------------------------
%U-value
Re_d1 = 4*qa_hc/(pi*di_d1*v_air);
Nu_d1 = 0.023*Re_d1^(0.8)*Pr_air^(0.4);
hi_d1 = lambda_air*Nu_d1/di_d1;
R_d1 = do_d1/(2*lambda_steel)*log(do_d1/di_d1)+do_d1/(2*lambda_insulation)*log((do_d1+2*insulation_d1)/do_d1)+do_d1/(do_d1+2*insulation_d1)*1/(hrad+hconv);
U_d1 = 1/R_d1;
tau_d1 = l_d1*pi*di_d1^2/(4*qa_hc);
k1_d1 = hi_d1*di_d1/(hi_d1*di_d1+U_d1*do_d1);
k2_d1 = U_d1*do_d1/(hi_d1*di_d1+U_d1*do_d1);
T1_d1 = di_d1*rho_air*cp_air/(4*hi_d1);
T2_d1 = (do_d1^2-di_d1^2)*rho_steel*cp_steel/(4*(hi_d1*di_d1+U_d1*do_d1));
nD_d1 = tau_d1*k2_d1/T1_d1;
mD_d1 = tau_d1*k1_d1/T1_d1;
KD_d1 = exp(-nD_d1);
TD1_d1 = exp(-mD_d1/2)*T2_d1;
TD2_d1 = exp(mD_d1/2)*T2_d1;

%--------------------------Duct 2------------------------------------------
%U-value
Re_d2 = 4*qa_hc/(pi*di_d2*v_air);
Nu_d2 = 0.023*Re_d2^(0.8)*Pr_air^(0.4);
hi_d2 = lambda_air*Nu_d2/di_d2;
R_d2 = do_d2/(2*lambda_steel)*log(do_d2/di_d2)+do_d2/(2*lambda_insulation)*log((do_d2+2*insulation_d2)/do_d2)+do_d2/(do_d2+2*insulation_d2)*1/(hrad+hconv);
U_d2 = 1/R_d2;
tau_d2 = l_d2*pi*di_d2^2/(4*qa_hc);
k1_d2 = hi_d2*di_d2/(hi_d2*di_d2+U_d2*do_d2);
k2_d2 = U_d2*do_d2/(hi_d2*di_d2+U_d2*do_d2);
T1_d2 = di_d2*rho_air*cp_air/(4*hi_d2);
T2_d2 = (do_d2^2-di_d2^2)*rho_steel*cp_steel/(4*(hi_d2*di_d2+U_d2*do_d2));
nD_d2 = tau_d2*k2_d2/T1_d2;
mD_d2 = tau_d2*k1_d2/T1_d2;
KD_d2 = exp(-nD_d2);
TD1_d2 = exp(-mD_d2/2)*T2_d2;
TD2_d2 = exp(mD_d2/2)*T2_d2;


